@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef __MATEKBD_UTIL_H__
@@ -29,5 +29,8 @@ extern GdkRectangle *matekbd_preview_load_position (void);
 
 extern void matekbd_preview_save_position (GdkRectangle * rect);
 
+/* Missing in glib */
+extern gchar **matekbd_strv_append (gchar ** arr, gchar * element);
+
 
 #endif
